# Tensor Network Guide

```{toctree}
:numbered:
:maxdepth: 2

tensor/tensor-basics
tensor/tensor-contraction
tensor/tensor-drawing
tensor/tensor-optimization
tensor/tensor-1d
tensor/tensor-2d
tensor/tensor-circuit
tensor/tensor-circuit-mps
tensor/tensor-design
```
